@@ -186,7 +186,7 @@ gdm_daemonify (void)
 
     pid = fork ();
     if (pid > 0) {
-        gchar *pidfile = gdm_get_value_string (GDM_KEY_PID_FILE);
+        gchar *pidfile = GDM_PID_FILE;
 
         errno = 0;
 	if ((pf = gdm_safe_fopen_w (pidfile)) != NULL) {
@@ -386,7 +386,7 @@ gdm_final_cleanup (void)
 
 	closelog ();
 
-	pidfile = gdm_get_value_string (GDM_KEY_PID_FILE);
+	pidfile = GDM_PID_FILE;
 	if (pidfile != NULL) {
 		VE_IGNORE_EINTR (g_unlink (pidfile));
 	}
@@ -563,7 +563,7 @@ deal_with_x_crashes (GdmDisplay *d)
 			    /* We couldn't run the script, just drop through */
 			    ;
 		    } else {
-			    /* Things went wrong, or the user's a wanker */
+			    /* Things went wrong */
 			    just_abort = TRUE;
 		    }
 	    }
@@ -1502,7 +1502,7 @@ main (int argc, char *argv[])
     /* get the name of the root user */
     gdm_root_user ();
 
-    pidfile = gdm_get_value_string (GDM_KEY_PID_FILE);
+    pidfile = GDM_PID_FILE;
 
     /* Check if another gdm process is already running */
     if (g_access (pidfile, R_OK) == 0) {
@@ -1517,8 +1517,6 @@ main (int argc, char *argv[])
 	    kill (pidv, 0) == 0 &&
 	    linux_only_is_running (pidv)) {
 		/* make sure the pid file doesn't get wiped */
-		gdm_set_value_string (GDM_KEY_PID_FILE, NULL);
-		pidfile = NULL;
 		VE_IGNORE_EINTR (fclose (pf));
 		gdm_fail (_("GDM already running. Aborting!"));
 	}
@@ -3182,7 +3180,7 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 				done_prefetch = TRUE;
 			}
 			return;
-		}
+                }
 
 		if (splitstr[0] != NULL) {
                        /*
@@ -3196,12 +3194,19 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
    				gdm_connection_printf (conn, "OK %s\n", retval);
    				g_free (retval);
 			} else {
-				if (gdm_is_valid_key ((gchar *)splitstr[0]))
+                                /* Check deprecated keys */
+                                if (strcmp (splitstr[0],
+                                         GDM_KEY_PID_FILE) == 0) {
+                                                gdm_connection_printf (conn,
+                                                        "OK %s\n", GDM_PID_FILE);
+                                                return;
+                                } else if (gdm_is_valid_key ((gchar *)splitstr[0])) {
 					gdm_connection_printf (conn, "OK \n");
-				else
+				} else {
        		         		gdm_connection_printf (conn,
 						"ERROR 50 Unsupported key <%s>\n",
 						splitstr[0]);
+				}
 			}
 			g_strfreev (splitstr);
 		}
@@ -3224,7 +3229,6 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 		gboolean sysmenu;
 
 		disp = gdm_connection_get_display (conn);
-		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 
 		/* Only allow locally authenticated connections */
 		if ( ! GDM_CONN_AUTHENTICATED (conn) ||
@@ -3236,6 +3240,7 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 			return;
 		}
 
+		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 		msg = g_string_new ("OK");
 
 		logout_action = disp->logout_action;
@@ -3275,7 +3280,6 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 		gboolean sysmenu;
 
 		disp = gdm_connection_get_display (conn);
-		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 
 		/* Only allow locally authenticated connections */
 		if ( ! GDM_CONN_AUTHENTICATED(conn) ||
@@ -3288,6 +3292,7 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 			return;
 		}
 
+		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 		if (strcmp (action, GDM_SUP_LOGOUT_ACTION_NONE) == 0) {
 			disp->logout_action = GDM_LOGOUT_ACTION_NONE;
 			was_ok = TRUE;
@@ -3328,7 +3333,6 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 		gboolean sysmenu;
 
 		disp = gdm_connection_get_display (conn);
-		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 
 		/* Only allow locally authenticated connections */
 		if ( ! GDM_CONN_AUTHENTICATED(conn) ||
@@ -3341,6 +3345,7 @@ gdm_handle_user_message (GdmConnection *conn, const gchar *msg, gpointer data)
 			return;
 		}
 
+		sysmenu = gdm_get_value_bool_per_display (disp->name, GDM_KEY_SYSTEM_MENU);
 		if (strcmp (action, GDM_SUP_LOGOUT_ACTION_NONE) == 0) {
 			safe_logout_action = GDM_LOGOUT_ACTION_NONE;
 			was_ok = TRUE;
