@@ -16,7 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include <config.h>
+#include "config.h"
+
 #include <glib/gi18n.h>
 #include <syslog.h>
 #include <pwd.h>
@@ -107,7 +108,7 @@ gdm_verify_user (GdmDisplay *d,
     gint reEnter, ret;
 #endif
 
-    if (local)
+    if (local && d->timed_login_ok)
 	    gdm_slave_greeter_ctl_no_ret (GDM_STARTTIMER, "");
 
     if (username == NULL) {
